package com.qmth.distributed.print.api.mark;

import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.teachcloud.common.entity.SysUser;
import com.qmth.teachcloud.common.util.Result;
import com.qmth.teachcloud.common.util.ResultUtil;
import com.qmth.teachcloud.common.util.ServletUtil;
import com.qmth.teachcloud.mark.params.MarkResult;
import com.qmth.teachcloud.mark.service.MarkService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
 * 评卷端接口 前端控制器
 * </p>
 *
 * @author xf
 * @since 2023-09-22
 */
@Api(tags = "评卷-评卷接口")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/mark")
public class MarkController {

    @Autowired
    private MarkService markService;

    @RequestMapping(value = "/getSetting", method = RequestMethod.POST)
    public Result getSetting(@RequestParam Long examId, @RequestParam String paperNumber,
                             @RequestParam Integer groupNumber) {
        SysUser user = (SysUser) ServletUtil.getRequestUser();
        return ResultUtil.ok(markService.getSetting(user, examId, paperNumber, groupNumber));
    }

    @RequestMapping(value = "/getStatus", method = RequestMethod.POST)
    public Result status(@RequestParam Long examId, @RequestParam String paperNumber,
                         @RequestParam Integer groupNumber) {
        SysUser user = (SysUser) ServletUtil.getRequestUser();
        return ResultUtil.ok(markService.getStatus(user.getId(), examId, paperNumber, groupNumber));
    }

    @RequestMapping(value = "/getGroup", method = RequestMethod.POST)
    @ResponseBody
    public Result getGroup(@RequestParam Long examId, @RequestParam String paperNumber) {
        SysUser user = (SysUser) ServletUtil.getRequestUser();
        return ResultUtil.ok(markService.getGroup(user.getId(), examId, paperNumber));
    }

    @RequestMapping(value = "/getTask", method = RequestMethod.POST)
    public Result getTask(@RequestParam Long examId, @RequestParam String paperNumber,
                          @RequestParam Integer groupNumber) {
        SysUser user = (SysUser) ServletUtil.getRequestUser();
        return ResultUtil.ok(markService.getTask(user.getId(), examId, paperNumber));
    }

    @RequestMapping(value = "/saveTask")
    public Result saveTask(HttpServletRequest request, @RequestBody MarkResult markResult) {
        SysUser user = (SysUser) ServletUtil.getRequestUser();
        return ResultUtil.ok(true);
    }

    @RequestMapping(value = "/getHistory", method = RequestMethod.POST)
    public Result getHistory(HttpServletRequest request, @RequestParam int pageNumber,
                             @RequestParam int pageSize, @RequestParam String order, @RequestParam String sort,
                             @RequestParam(required = false) String secretNumber, @RequestParam(required = false) Double markerScore) {
        SysUser user = (SysUser) ServletUtil.getRequestUser();
        return ResultUtil.ok(markService.getHistory(user.getId()));
    }

    @RequestMapping(value = "/updateSetting", method = RequestMethod.POST)
    public Result updateSetting(HttpServletRequest request, @RequestParam(required = false) String uiSetting,
                                @RequestParam(required = false) String mode) {
        SysUser user = (SysUser) ServletUtil.getRequestUser();
        
        return ResultUtil.ok(true);
    }

    @RequestMapping("/clear")
    public Result clear(HttpServletRequest request) {
        SysUser user = (SysUser) ServletUtil.getRequestUser();
        markService.clear(user.getId());
        return ResultUtil.ok(true);
    }
}
